@@ -67,6 +67,7 @@ enum{
   PROP_0,
   PROP_SOUNDCARD,
   PROP_AUDIO_FILE,
+  PROP_TIC,
 };
 
 static gpointer ags_export_thread_parent_class = NULL;
@@ -75,11 +76,9 @@ static AgsConnectableInterface *ags_export_thread_parent_connectable_interface;
 GType
 ags_export_thread_get_type()
 {
-  static volatile gsize g_define_type_id__volatile = 0;
-
-  if(g_once_init_enter (&g_define_type_id__volatile)){
-    GType ags_type_export_thread;
+  static GType ags_type_export_thread = 0;
 
+  if(!ags_type_export_thread){
     static const GTypeInfo ags_export_thread_info = {
       sizeof (AgsExportThreadClass),
       NULL, /* base_init */
@@ -106,11 +105,9 @@ ags_export_thread_get_type()
     g_type_add_interface_static(ags_type_export_thread,
 				AGS_TYPE_CONNECTABLE,
 				&ags_connectable_interface_info);
-
-    g_once_init_leave (&g_define_type_id__volatile, ags_type_export_thread);
   }
-
-  return g_define_type_id__volatile;
+  
+  return (ags_type_export_thread);
 }
 
 void
@@ -137,7 +134,7 @@ ags_export_thread_class_init(AgsExportThreadClass *export_thread)
    *
    * The assigned #AgsSoundcard.
    * 
-   * Since: 1.0.0
+   * Since: 2.0.0
    */
   param_spec = g_param_spec_object("soundcard",
 				   i18n_pspec("soundcard assigned to"),
@@ -153,7 +150,7 @@ ags_export_thread_class_init(AgsExportThreadClass *export_thread)
    *
    * The assigned #AgsAudioFile.
    * 
-   * Since: 1.0.0
+   * Since: 2.0.0
    */
   param_spec = g_param_spec_object("audio-file",
 				   i18n_pspec("audio file to write"),
@@ -164,6 +161,24 @@ ags_export_thread_class_init(AgsExportThreadClass *export_thread)
 				  PROP_AUDIO_FILE,
 				  param_spec);
 
+  /**
+   * AgsExportThread:tic:
+   *
+   * The tic.
+   * 
+   * Since: 2.0.0
+   */
+  param_spec =  g_param_spec_uint("tic",
+				  i18n_pspec("tic"),
+				  i18n_pspec("The tic"),
+				  0,
+				  G_MAXUINT,
+				  0,
+				  G_PARAM_READABLE | G_PARAM_WRITABLE);
+  g_object_class_install_property(gobject,
+				  PROP_TIC,
+				  param_spec);
+
   /* AgsThread */
   thread = (AgsThreadClass *) export_thread;
 
@@ -193,8 +208,7 @@ ags_export_thread_init(AgsExportThread *export_thread)
   thread = (AgsThread *) export_thread;
 
   g_atomic_int_or(&(thread->flags),
-		  (AGS_THREAD_START_SYNCED_FREQ |
-		   AGS_THREAD_INTERMEDIATE_POST_SYNC));
+		  (AGS_THREAD_START_SYNCED_FREQ));
   
   config = ags_config_get_instance();
   
@@ -321,6 +335,11 @@ ags_export_thread_set_property(GObject *gobject,
       export_thread->audio_file = audio_file;
     }
     break;
+  case PROP_TIC:
+    {
+      export_thread->tic = g_value_get_uint(value);
+    }
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(gobject, prop_id, param_spec);
     break;
@@ -348,6 +367,11 @@ ags_export_thread_get_property(GObject *gobject,
       g_value_set_object(value, export_thread->audio_file);
     }
     break;
+  case PROP_TIC:
+    {
+      g_value_set_uint(value, export_thread->tic);
+    }
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(gobject, prop_id, param_spec);
     break;
@@ -436,7 +460,6 @@ ags_export_thread_run(AgsThread *thread)
 {
   AgsExportThread *export_thread;
 
-  AgsMutexManager *mutex_manager;
   AgsSoundcard *soundcard;
 
   void *soundcard_buffer;
@@ -457,25 +480,14 @@ ags_export_thread_run(AgsThread *thread)
   }
 
   /*  */
-  mutex_manager = ags_mutex_manager_get_instance();
-  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
-
-  pthread_mutex_lock(application_mutex);
-
-  mutex = ags_mutex_manager_lookup(mutex_manager,
-				   (GObject *) export_thread->soundcard);
-
-  pthread_mutex_unlock(application_mutex);
-
-  /*  */
-  pthread_mutex_lock(mutex);
-
   soundcard = AGS_SOUNDCARD(export_thread->soundcard);
 
-  if(AGS_IS_JACK_DEVOUT(soundcard) ||
-     AGS_IS_PULSE_DEVOUT(soundcard)){
+  if(AGS_IS_DEVOUT(soundcard)){
+    soundcard_buffer = ags_soundcard_get_buffer(soundcard);
+  }else if(AGS_IS_JACK_DEVOUT(soundcard) ||
+	   AGS_IS_PULSE_DEVOUT(soundcard)){
     soundcard_buffer = ags_soundcard_get_prev_buffer(soundcard);
-  }else{
+  }else if(AGS_IS_CORE_AUDIO_DEVOUT(soundcard)){
     soundcard_buffer = ags_soundcard_get_buffer(soundcard);
   }
   
@@ -485,12 +497,16 @@ ags_export_thread_run(AgsThread *thread)
 			    &buffer_size,
 			    &format);
 
+  ags_soundcard_lock_buffer(soundcard,
+			    soundcard_buffer);
+  
   ags_audio_file_write(export_thread->audio_file,
 		       soundcard_buffer,
 		       (guint) buffer_size,
 		       format);
-  
-  pthread_mutex_unlock(mutex);
+
+  ags_soundcard_unlock_buffer(soundcard,
+			    soundcard_buffer);
 }
 
 void
@@ -514,7 +530,7 @@ ags_export_thread_stop(AgsThread *thread)
  * Returns: the matching #AgsExportThread, if not
  * found %NULL.
  * 
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 AgsExportThread*
 ags_export_thread_find_soundcard(AgsExportThread *export_thread,
@@ -542,11 +558,11 @@ ags_export_thread_find_soundcard(AgsExportThread *export_thread,
  * @soundcard: the #AgsSoundcard
  * @audio_file: the output file
  *
- * Create a new #AgsExportThread.
+ * Create a new instance of #AgsExportThread.
  *
  * Returns: the new #AgsExportThread
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 AgsExportThread*
 ags_export_thread_new(GObject *soundcard, AgsAudioFile *audio_file)
