@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2015 Joël Krähemann
+ * Copyright (C) 2005-2018 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -35,7 +35,6 @@
 #include <ags/i18n.h>
 
 void ags_returnable_thread_class_init(AgsReturnableThreadClass *returnable_thread);
-void ags_returnable_thread_connectable_interface_init(AgsConnectableInterface *connectable);
 void ags_returnable_thread_init(AgsReturnableThread *returnable_thread);
 void ags_returnable_thread_set_property(GObject *gobject,
 					guint prop_id,
@@ -45,8 +44,6 @@ void ags_returnable_thread_get_property(GObject *gobject,
 					guint prop_id,
 					GValue *value,
 					GParamSpec *param_spec);
-void ags_returnable_thread_connect(AgsConnectable *connectable);
-void ags_returnable_thread_disconnect(AgsConnectable *connectable);
 void ags_returnable_thread_dispose(GObject *gobject);
 void ags_returnable_thread_finalize(GObject *gobject);
 
@@ -69,6 +66,7 @@ void ags_returnable_thread_resume(AgsThread *thread);
 enum{
   PROP_0,
   PROP_THREAD_POOL,
+  PROP_SAFE_DATA,
 };
 
 enum{
@@ -77,7 +75,6 @@ enum{
 };
 
 static gpointer ags_returnable_thread_parent_class = NULL;
-static AgsConnectableInterface *ags_returnable_thread_parent_connectable_interface;
 static guint returnable_thread_signals[LAST_SIGNAL];
 
 GType
@@ -86,8 +83,8 @@ ags_returnable_thread_get_type()
   static volatile gsize g_define_type_id__volatile = 0;
 
   if(g_once_init_enter (&g_define_type_id__volatile)){
-    GType ags_type_returnable_thread;
-    
+    GType ags_type_returnable_thread = 0;
+
     static const GTypeInfo ags_returnable_thread_info = {
       sizeof (AgsReturnableThreadClass),
       NULL, /* base_init */
@@ -100,22 +97,12 @@ ags_returnable_thread_get_type()
       (GInstanceInitFunc) ags_returnable_thread_init,
     };
 
-    static const GInterfaceInfo ags_connectable_interface_info = {
-      (GInterfaceInitFunc) ags_returnable_thread_connectable_interface_init,
-      NULL, /* interface_finalize */
-      NULL, /* interface_data */
-    };
-
     ags_type_returnable_thread = g_type_register_static(AGS_TYPE_THREAD,
 							"AgsReturnableThread",
 							&ags_returnable_thread_info,
 							0);
 
-    g_type_add_interface_static(ags_type_returnable_thread,
-				AGS_TYPE_CONNECTABLE,
-				&ags_connectable_interface_info);
-
-    g_once_init_leave (&g_define_type_id__volatile, ags_type_returnable_thread);
+    g_once_init_leave(&g_define_type_id__volatile, ags_type_returnable_thread);
   }
 
   return g_define_type_id__volatile;
@@ -147,7 +134,7 @@ ags_returnable_thread_class_init(AgsReturnableThreadClass *returnable_thread)
    *
    * The assigned #AgsThreadPool providing default settings.
    * 
-   * Since: 1.0.0
+   * Since: 2.0.0
    */
   param_spec = g_param_spec_object("thread-pool",
 				   i18n_pspec("assigned thread pool"),
@@ -177,7 +164,7 @@ ags_returnable_thread_class_init(AgsReturnableThreadClass *returnable_thread)
    * The ::safe-run is invoked durin AgsThread::run as
    * a context safe wrapper.
    *
-   * Since: 1.0.0
+   * Since: 2.0.0
    */
   returnable_thread_signals[SAFE_RUN] =
     g_signal_new("safe-run",
@@ -190,15 +177,6 @@ ags_returnable_thread_class_init(AgsReturnableThreadClass *returnable_thread)
 
 }
 
-void
-ags_returnable_thread_connectable_interface_init(AgsConnectableInterface *connectable)
-{
-  ags_returnable_thread_parent_connectable_interface = g_type_interface_peek_parent(connectable);
-
-  connectable->connect = ags_returnable_thread_connect;
-  connectable->disconnect = ags_returnable_thread_disconnect;
-}
-
 void
 ags_returnable_thread_init(AgsReturnableThread *returnable_thread)
 {
@@ -284,22 +262,6 @@ ags_returnable_thread_get_property(GObject *gobject,
   }
 }
 
-void
-ags_returnable_thread_connect(AgsConnectable *connectable)
-{
-  ags_returnable_thread_parent_connectable_interface->connect(connectable);
-
-  /* empty */
-}
-
-void
-ags_returnable_thread_disconnect(AgsConnectable *connectable)
-{
-  ags_returnable_thread_parent_connectable_interface->disconnect(connectable);
-
-  /* empty */
-}
-
 void
 ags_returnable_thread_dispose(GObject *gobject)
 {
@@ -410,6 +372,69 @@ ags_returnable_thread_resume(AgsThread *thread)
   /* empty */
 }
 
+/**
+ * ags_returnable_thread_test_flags:
+ * @returnable_thread: the #AgsReturnableThread
+ * @flags: the flags
+ *
+ * Test @flags to be set on @returnable_thread.
+ * 
+ * Returns: %TRUE if flags are set, else %FALSE
+ *
+ * Since: 2.0.0
+ */
+gboolean
+ags_returnable_thread_test_flags(AgsReturnableThread *returnable_thread, guint flags)
+{
+  gboolean retval;  
+
+  if(!AGS_IS_RETURNABLE_THREAD(returnable_thread)){
+    return(FALSE);
+  }
+  
+  retval = ((flags & (g_atomic_int_get(&(returnable_thread->flags)))) != 0) ? TRUE: FALSE;
+    
+  return(retval);
+}
+
+/**
+ * ags_returnable_thread_set_flags:
+ * @returnable_thread: the #AgsReturnableThread
+ * @flags: the flags
+ *
+ * Set flags.
+ * 
+ * Since: 2.0.0
+ */
+void
+ags_returnable_thread_set_flags(AgsReturnableThread *returnable_thread, guint flags)
+{
+  if(!AGS_IS_RETURNABLE_THREAD(returnable_thread)){
+    return;
+  }
+
+  g_atomic_int_or(&(returnable_thread->flags), flags);
+}
+
+/**
+ * ags_returnable_thread_unset_flags:
+ * @returnable_thread: the #AgsReturnableThread
+ * @flags: the flags
+ *
+ * Unset flags.
+ * 
+ * Since: 2.0.0
+ */
+void
+ags_returnable_thread_unset_flags(AgsReturnableThread *returnable_thread, guint flags)
+{
+  if(!AGS_IS_RETURNABLE_THREAD(returnable_thread)){
+    return;
+  }
+
+  g_atomic_int_and(&(returnable_thread->flags), (~flags));
+}
+
 /**
  * ags_returnable_thread_connect_safe_run:
  * @returnable_thread: the thread to connect
@@ -417,7 +442,7 @@ ags_returnable_thread_resume(AgsThread *thread)
  *
  * Connects @callback to @thread.
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 void
 ags_returnable_thread_connect_safe_run(AgsReturnableThread *returnable_thread, AgsReturnableThreadCallback callback)
@@ -436,7 +461,7 @@ ags_returnable_thread_connect_safe_run(AgsReturnableThread *returnable_thread, A
  *
  * Disconnects callback of @thread.
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 void
 ags_returnable_thread_disconnect_safe_run(AgsReturnableThread *returnable_thread)
@@ -455,11 +480,11 @@ ags_returnable_thread_disconnect_safe_run(AgsReturnableThread *returnable_thread
  * ags_returnable_thread_new:
  * @thread_pool: the #AgsThreadPool
  *
- * Create a new #AgsReturnableThread.
+ * Create a new instance of #AgsReturnableThread.
  *
  * Returns: the new #AgsReturnableThread
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 AgsReturnableThread*
 ags_returnable_thread_new(GObject *thread_pool)
